@@ -115,6 +115,7 @@ class ChangeAuditor:
             attribute="allocated_functions",
             element="<LogicalFunction 'Root Logical Function' (f2...)>",
             uuid="f28ec0f8-f3b3-43a0-8af7-79f194b29a2d",
+        ),
         Deletion(
             parent="0d2edb8f-fa34-4e73-89ec-fb9a63001440",
             attribute="components",
@@ -231,14 +232,14 @@ class ChangeAuditor:
                 oval = getattr(obj, attr_name)
                 nrepr = self._get_value_repr(value)
                 orepr = self._get_value_repr(oval)
-                params = (obj.uuid, attr_name, nrepr, orepr)
+                events = [EventType(obj.uuid, attr_name, nrepr, orepr)]
             elif event.endswith("setitem"):
                 assert len(args) == 4
                 obj, attr_name, index, value = args
                 nrepr = self._get_value_repr(value)
                 oval = getattr(obj, attr_name)[index]
                 orepr = self._get_value_repr(oval)
-                params = (obj.uuid, attr_name, nrepr, orepr)
+                events = [EventType(obj.uuid, attr_name, nrepr, orepr)]
             elif event.endswith("delete"):
                 assert len(args) == 3
                 obj, attr_name, index = args
@@ -247,22 +248,34 @@ class ChangeAuditor:
                 if index is not None:
                     oval = oval[index]
 
-                assert isinstance(oval, common.GenericElement)
-                orepr = self._get_value_repr(oval)
-                params = (obj.uuid, attr_name, orepr, oval.uuid)
+                if not isinstance(oval, common.GenericElement):
+                    assert isinstance(oval, common.ElementList)
+                    events = []
+                    assert EventType is Deletion
+                    for elt in oval:
+                        event_type = EventType(
+                            obj.uuid,
+                            attr_name,
+                            self._get_value_repr(elt),
+                            elt.uuid,
+                        )
+                        events.append(event_type)
+                else:
+                    orepr = self._get_value_repr(oval)
+                    events = [EventType(obj.uuid, attr_name, orepr, oval.uuid)]
             elif event.endswith("insert"):
                 assert len(args) == 4
                 obj, attr_name, _, value = args
                 nrepr = self._get_value_repr(value)
                 assert isinstance(value, common.GenericElement)
-                params = (obj.uuid, attr_name, nrepr, value.uuid)
+                events = [EventType(obj.uuid, attr_name, nrepr, value.uuid)]
             elif event.endswith("create"):
                 assert len(args) == 3
                 obj, attr_name, value = args
                 repr = self._get_value_repr(value)
-                params = (obj.uuid, attr_name, repr, value.uuid)
+                events = [EventType(obj.uuid, attr_name, repr, value.uuid)]
 
-            self.context.append(EventType(*params))
+            self.context.extend(events)
 
     def _get_value_repr(self, value: t.Any) -> str | t.Any:
         if hasattr(value, "_short_repr_"):
@@ -362,7 +375,7 @@ class RMReporter:
     def _assign_module(self, change: Change) -> LiveDocID | TrackerID | None:
         try:
             obj = self.model.by_uuid(change.parent)
-            while not isinstance(obj, reqif.RequirementsModule):
+            while not isinstance(obj, reqif.CapellaModule):
                 obj = obj.parent
             return obj.identifier
         except (KeyError, AttributeError):
@@ -407,7 +420,7 @@ class RMReporter:
             main_message = generate_main_message(self.categories.items())
             main = "\n".join((main_message, "\n".join(list_lines) + "\n"))
 
-        summary = f"{summary} from rev.{tool_metadata['revision']} [skip ci]\n"
+        summary = f"{summary} from rev.{tool_metadata['revision']}\n"
         rm_bridge_dependencies = get_dependencies()
         dependencies = "\n".join(
             (
@@ -438,20 +451,20 @@ class RMReporter:
         return ext_count, mod_count, del_count, type_count
 
     def _is_reqtype_change(self, change: Change) -> bool:
-        if isinstance(change, Modification):
+        if isinstance(change, (Modification, Deletion)):
             obj = self.model.by_uuid(change.parent)
-        else:
+        elif isinstance(change, Extension):
             obj = self.model.by_uuid(change.uuid)
 
         return type(obj) in {
             reqif.AttributeDefinition,
             reqif.AttributeDefinitionEnumeration,
             reqif.DataTypeDefinition,
-            reqif.EnumDataTypeDefinition,
+            reqif.EnumerationDataTypeDefinition,
             reqif.EnumValue,
             reqif.ModuleType,
             reqif.RelationType,
-            reqif.RequirementsTypesFolder,
+            reqif.CapellaTypesFolder,
             reqif.RequirementType,
         }
 
